@@ -22,15 +22,12 @@ require 'spec_helper'
 describe 'barbican::plugins::dogtag' do
   let :default_params do
     {
-      :dogtag_plugin_ensure_package     => 'present',
-      :dogtag_plugin_pem_path           => '<SERVICE DEFAULT>',
-      :dogtag_plugin_dogtag_host        => '<SERVICE DEFAULT>',
-      :dogtag_plugin_dogtag_port        => '<SERVICE DEFAULT>',
-      :dogtag_plugin_nss_db_path        => '<SERVICE DEFAULT>',
-      :dogtag_plugin_simple_cmc_profile => '<SERVICE DEFAULT>',
-      :dogtag_plugin_ca_expiration_time => '<SERVICE DEFAULT>',
-      :dogtag_plugin_plugin_working_dir => '<SERVICE DEFAULT>',
-      :global_default                   => false,
+      :dogtag_plugin_ensure_package => 'present',
+      :dogtag_plugin_pem_path       => '<SERVICE DEFAULT>',
+      :dogtag_plugin_dogtag_host    => '<SERVICE DEFAULT>',
+      :dogtag_plugin_dogtag_port    => '<SERVICE DEFAULT>',
+      :dogtag_plugin_nss_db_path    => '<SERVICE DEFAULT>',
+      :global_default               => false,
     }
   end
 
@@ -39,15 +36,12 @@ describe 'barbican::plugins::dogtag' do
        :dogtag_plugin_nss_password => 'password',
      },
      {
-       :dogtag_plugin_pem_path           => 'path_to_pem_file',
-       :dogtag_plugin_dogtag_host        => 'dogtag_host',
-       :dogtag_plugin_dogtag_port        => '1234',
-       :dogtag_plugin_nss_db_path        => 'path_to_nss_db',
-       :dogtag_plugin_nss_password       => 'password',
-       :dogtag_plugin_simple_cmc_profile => 'caServerCert',
-       :dogtag_plugin_ca_expiration_time => '100',
-       :dogtag_plugin_plugin_working_dir => 'path_to_working_dir',
-       :global_default                   => true,
+       :dogtag_plugin_pem_path     => 'path_to_pem_file',
+       :dogtag_plugin_dogtag_host  => 'dogtag_host',
+       :dogtag_plugin_dogtag_port  => '1234',
+       :dogtag_plugin_nss_db_path  => 'path_to_nss_db',
+       :dogtag_plugin_nss_password => 'password',
+       :global_default             => true,
       }
     ].each do |param_set|
       context "when #{param_set == {} ? "using default" : "specifying"} class parameters" do
@@ -71,9 +65,6 @@ describe 'barbican::plugins::dogtag' do
           should contain_barbican_config('dogtag_plugin/dogtag_port').with_value(param_hash[:dogtag_plugin_dogtag_port])
           should contain_barbican_config('dogtag_plugin/nss_db_path').with_value(param_hash[:dogtag_plugin_nss_db_path])
           should contain_barbican_config('dogtag_plugin/nss_password').with_value(param_hash[:dogtag_plugin_nss_password]).with_secret(true)
-          should contain_barbican_config('dogtag_plugin/simple_cmc_profile').with_value(param_hash[:dogtag_plugin_simple_cmc_profile])
-          should contain_barbican_config('dogtag_plugin/ca_expiration_time').with_value(param_hash[:dogtag_plugin_ca_expiration_time])
-          should contain_barbican_config('dogtag_plugin/plugin_working_dir').with_value(param_hash[:dogtag_plugin_plugin_working_dir])
           should contain_barbican_config('secretstore:dogtag/secret_store_plugin').with_value('dogtag_crypto')
           should contain_barbican_config('secretstore:dogtag/global_default').with_value(param_hash[:global_default])
         }
